==> codeforlife_portal-1.2.0-py2.py3-none-any.whl: portal/templatetags/table_tags.py <==
# -*- coding: utf-8 -*-
# Code for Life
#
# Copyright (C) 2019, Ocado Innovation Limited
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# ADDITIONAL TERMS – Section 7 GNU General Public Licence
#
# This licence does not grant any right, title or interest in any “Ocado” logos,
# trade names or the trademark “Ocado” or any other trademarks or domain names
# owned by Ocado Innovation Limited or the Ocado group of companies or any other
# distinctive brand features of “Ocado” as may be secured from time to time. You
# must not distribute any modification of this program using the trademark
# “Ocado” or claim any affiliation or association with Ocado or its employees.
#
# You are not authorised to use the name Ocado (or any of its trade names) or
# the names of any author or contributor in advertising or for publicity purposes
# pertaining to the distribution of this program, without the prior written
# authorisation of Ocado.
#
# Any propagation, distribution or conveyance of this program must include this
# copyright notice and these terms. You must not misrepresent the origins of this
# program; modified versions of the program must be marked as such and not
# identified as the original program.
from django import template
from django.template.defaultfilters import floatformat

register = template.Library()


@register.filter(name='tableformat')
def tableformat(entry):

    if entry is None:
        return "-"
    elif is_numerical(entry):
        return floatformat(entry, -2)
    else:
        return entry


def is_numerical(str):
    try:
        float(str)
        return True
    except (ValueError, TypeError):
        return False


@register.inclusion_tag('portal/partials/resource_sheets_table.html')
def resource_sheets_table(table):
    """
    This function takes in a dictionary which mirrors the table of resource sheets for a key stage section.
    The dictionary has a starting session index, and the actual table content. The table content is a 2D list:
    a list of sessions, each holding a list of resource sheets.
    Some sessions have more resource sheets than others, as such the table has some rows which contain less columns.
    The lengthen_list function is called to add empty columns to the smaller rows.
    :param table: A dictionary containing a starting session index (integer) and the content of the table (2D list)
    :return: A dictionary containing the table with all rows now of the same length, and the starting session index.
    """
    table_content = table['content']
    max_count = len(max(table_content, key=len))
    return {'table': [lengthen_list(max_count, column) for column in table_content],
            'starting_session_index': table['starting_session_index']}


def lengthen_list(length, list):
    return list + [[]] * (length - len(list))

==> codeforlife_portal-2.9.1-py2.py3-none-any.whl: portal/templatetags/table_tags.py <==
# -*- coding: utf-8 -*-
# Code for Life
#
# Copyright (C) 2019, Ocado Innovation Limited
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# ADDITIONAL TERMS – Section 7 GNU General Public Licence
#
# This licence does not grant any right, title or interest in any “Ocado” logos,
# trade names or the trademark “Ocado” or any other trademarks or domain names
# owned by Ocado Innovation Limited or the Ocado group of companies or any other
# distinctive brand features of “Ocado” as may be secured from time to time. You
# must not distribute any modification of this program using the trademark
# “Ocado” or claim any affiliation or association with Ocado or its employees.
#
# You are not authorised to use the name Ocado (or any of its trade names) or
# the names of any author or contributor in advertising or for publicity purposes
# pertaining to the distribution of this program, without the prior written
# authorisation of Ocado.
#
# Any propagation, distribution or conveyance of this program must include this
# copyright notice and these terms. You must not misrepresent the origins of this
# program; modified versions of the program must be marked as such and not
# identified as the original program.
from django import template
from django.template.defaultfilters import floatformat

register = template.Library()


@register.filter(name="tableformat")
def tableformat(entry):

    if entry is None:
        return "-"
    elif is_numerical(entry):
        return floatformat(entry, -2)
    else:
        return entry


def is_numerical(str):
    try:
        float(str)
        return True
    except (ValueError, TypeError):
        return False


@register.inclusion_tag("portal/partials/resource_sheets_table.html")
def resource_sheets_table(table):
    """
    This function takes in a dictionary which mirrors the table of resource sheets for a key stage section.
    The dictionary has a starting session index, and the actual table content. The table content is a 2D list:
    a list of sessions, each holding a list of resource sheets.
    Some sessions have more resource sheets than others, as such the table has some rows which contain less columns.
    The lengthen_list function is called to add empty columns to the smaller rows.
    :param table: A dictionary containing a starting session index (integer) and the content of the table (2D list)
    :return: A dictionary containing the table with all rows now of the same length, and the starting session index.
    """
    table_content = table["content"]
    max_count = len(max(table_content, key=len))
    return {
        "table": [lengthen_list(max_count, column) for column in table_content],
        "starting_session_index": table["starting_session_index"],
    }


def lengthen_list(length, list):
    return list + [[]] * (length - len(list))
